function [screwaxis,screwloc] = getPoleAxis(modelname,node,mode)
%     
%   M. Nijenhuis, 2021.
%   Determine the instantaneous rotation axis of a rigid body
%   corresponding with a certain eigenmode of the system.
% 
%   modelname: name of .dat-file (without extension)
%   node: (translational) node to which the rigid body is connected
%   mode: number of the eigenmode
% 
%   screwaxis: vector representing the rotation (screw) axis
%   screwloc: a point on the rotation axis. This point is the point that is
%   closest to the specified translation node.
% 
%   Note that this script currently evaluates the model at the first
%   timestep. Also, it is assumed that the rotation node has number node+1.
%
%   Change 2021: 
%   accounting for warping node counting (since SPACAR Light 1.30)

    t = 1;
    transnode = (node-1)*3+1;
    rotnode = transnode +1;
    
    dx_store = getfrsbf([modelname '.sbd'],'dx');
    x_store = getfrsbf([modelname '.sbd'],'x');
    lnp = getfrsbf([modelname '.sbd'],'lnp');
    tdef = getfrsbf([modelname '.sbd'],'tdef');
    nx = getfrsbf([modelname '.sbd'],'nx');
    ndof = getfrsbf([modelname '.sbd'],'ndof');
    nddof = getfrsbf([modelname '.sbd'],'ndof');
    nxp = getfrsbf([modelname '.sbd'],'nxp');
    nep = getfrsbf([modelname '.sbd'],'nep');
    M = getfrsbf([modelname '.sbm'],'M0',t);
    K = getfrsbf([modelname '.sbm'],'K0',t) + ...
        getfrsbf([modelname '.sbm'],'N0',t) + ...
        getfrsbf([modelname '.sbm'],'G0',t);
    
    if tdef == 1
        x_store = x_store';
        dx_store = reshape(dx_store,1,nx*ndof);
    end
        
    dx = reshape(dx_store(t,:),nx,ndof);
    x = x_store(t,:);
    
    dx = dx(:,[ nxp(3)+(1:nxp(4)) nxp(3)+nxp(4)+nep(3)+(1:nep(4)) ]);
    [V,D] = eig(K(1:nddof,1:nddof),M(1:nddof,1:nddof));
    D  = diag(D); 
    [~,o] = sort(abs(D(:)));
    V = V(:,o);
    d = D(o);
    eigfreq = sqrt(d)*[1 1/(2*pi)]; % [rad/s Hz]
    disp(eigfreq(mode,2));
    V = V*diag(1./sqrt(diag(V'*V)));
    eigvec = dx*V(:,mode);
    
    transcoord = x(:,lnp(transnode,1:3));
    rotcoord = x(:,lnp(rotnode,1:4));
    la0 = rotcoord(1);
    la1 = rotcoord(2);
    la2 = rotcoord(3);
    la3 = rotcoord(4);

    bigLab = [
        -la1 la0 -la3 la2
        -la2 la3 la0 -la1
        -la3 -la2 la1 la0
    ];
    
    deltrans = eigvec(lnp(transnode,1:3));
    dellab = eigvec(lnp(rotnode,1:4));
    
    delrot = 2*bigLab*dellab;
    screwloc = transcoord' + ...
        cross(delrot,deltrans)/norm(delrot)^2;
    
    screwaxis = dellab(2:4);
    screwaxis = screwaxis / norm(screwaxis);
        
%         xnode = x(:,lnp(transnode,1));
%         ynode = x(:,lnp(transnode,2));
    
%         for j=1:ndof
%             
%             dxdq = dx(lnp(transnode,1),j);
%             dydq = dx(lnp(transnode,2),j);
%             dphdq = dx(lnp(rotnode,1),j);
%         
%             dxdph = dxdq/dphdq;
%             dydph = dydq/dphdq;
% 
%             xp(i,j) = xnode - dydph;
%             yp(i,j) = ynode + dxdph;
%         
%         end
    
end